Substance D
===========

.. image:: https://travis-ci.org/Pylons/substanced.png?branch=master
        :target: https://travis-ci.org/Pylons/substanced

.. image:: https://readthedocs.org/projects/substanced/badge?version=latest
        :target: http://docs.pylonsproject.org/projects/substanced
        :alt: Latest Documentation Status

An application server built upon the Pyramid web framework.  It provides a
user interface for managing content as well as libraries and utilities which
make it easy to create applications.

Visit the main website at http://substanced.net for FAQs and documentation.

There is a mailing list: https://groups.google.com/group/substanced-users

The code is at https://github.com/Pylons/substanced

The IRC channel is at irc://freenode.net/#substanced
